@@ -84,6 +84,29 @@ extern "C" void pdf_free(pdf_t *pdf)
   delete pdf;
 }
 
+/*
+ * 'pdf_pages()' - Count number of pages in file
+ *                         using QPDF.
+ * I - Filename to open
+ * O - Number of pages or -1 on error
+ */
+int pdf_pages(const char *filename)
+{
+  QPDF *pdf = new QPDF();
+  if (pdf) {
+    try{
+      pdf->processFile(filename);
+    } catch(...) {
+      pdf_free(pdf);
+      return -1;
+    }
+    int pages = (pdf->getAllPages()).size();
+    pdf_free(pdf);
+    return pages;
+  } else
+    return -1;
+}
+
 
 /**
  * 'pdf_prepend_stream' - Prepend a stream to the contents of a specified
